@@ -141,6 +141,75 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAlertList(self, request):
+        """告警中心全量告警列表接口
+
+        :param request: Request instance for DescribeAlertList.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeAlertListRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeAlertListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAlertList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAlertListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAssetViewVulRiskList(self, request):
+        """获取资产视角的漏洞风险列表
+
+        :param request: Request instance for DescribeAssetViewVulRiskList.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeAssetViewVulRiskListRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeAssetViewVulRiskListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAssetViewVulRiskList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAssetViewVulRiskListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCFWAssetStatistics(self, request):
+        """云防资产中心统计数据
+
+        :param request: Request instance for DescribeCFWAssetStatistics.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeCFWAssetStatisticsRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeCFWAssetStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCFWAssetStatistics", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCFWAssetStatisticsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCVMAssetInfo(self, request):
         """cvm详情
 
@@ -165,7 +234,7 @@ class CsipClient(AbstractClient):
 
 
     def DescribeCVMAssets(self, request):
-        """cvm列表
+        """获取cvm列表
 
         :param request: Request instance for DescribeCVMAssets.
         :type request: :class:`tencentcloud.csip.v20221121.models.DescribeCVMAssetsRequest`
@@ -716,6 +785,29 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTopAttackInfo(self, request):
+        """查询TOP攻击信息
+
+        :param request: Request instance for DescribeTopAttackInfo.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeTopAttackInfoRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeTopAttackInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTopAttackInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTopAttackInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeVULRiskAdvanceCFGList(self, request):
         """查询漏洞风险高级配置
 
@@ -739,6 +831,29 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeVULRiskDetail(self, request):
+        """获取漏洞展开详情
+
+        :param request: Request instance for DescribeVULRiskDetail.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeVULRiskDetailRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeVULRiskDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeVULRiskDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeVULRiskDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeVpcAssets(self, request):
         """获取vpc列表
 
@@ -762,6 +877,29 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeVulViewVulRiskList(self, request):
+        """获取漏洞视角的漏洞风险列表
+
+        :param request: Request instance for DescribeVulViewVulRiskList.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeVulViewVulRiskListRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeVulViewVulRiskListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeVulViewVulRiskList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeVulViewVulRiskListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyOrganizationAccountStatus(self, request):
         """修改集团账号状态
 
@@ -808,6 +946,29 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyRiskCenterScanTask(self, request):
+        """修改风险中心扫描任务
+
+        :param request: Request instance for ModifyRiskCenterScanTask.
+        :type request: :class:`tencentcloud.csip.v20221121.models.ModifyRiskCenterScanTaskRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.ModifyRiskCenterScanTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyRiskCenterScanTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyRiskCenterScanTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StopRiskCenterTask(self, request):
         """停止扫风险中心扫描任务
 
@@ -824,6 +985,29 @@ class CsipClient(AbstractClient):
             model = models.StopRiskCenterTaskResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateAlertStatusList(self, request):
+        """批量告警状态处理接口
+
+        :param request: Request instance for UpdateAlertStatusList.
+        :type request: :class:`tencentcloud.csip.v20221121.models.UpdateAlertStatusListRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.UpdateAlertStatusListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateAlertStatusList", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateAlertStatusListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
